pub struct Session {Show 19 fields
client: OnceCell<TokioDrop<Client>>,
sidebar_list_model: OnceCell<SidebarListModel>,
user: OnceCell<User>,
state: Cell<SessionState>,
is_homeserver_reachable: Cell<bool>,
is_offline: Cell<bool>,
settings: OnceCell<SessionSettings>,
global_account_data: OnceCell<GlobalAccountData>,
notifications: Notifications,
ignored_users: IgnoredUsers,
user_sessions: UserSessionsList,
security: SessionSecurity,
remote_cache: OnceCell<RemoteCache>,
session_changes_handle: RefCell<Option<AbortHandle>>,
sync_handle: RefCell<Option<AbortHandle>>,
network_monitor_handler_id: RefCell<Option<SignalHandlerId>>,
homeserver_reachable_lock: Mutex<()>,
homeserver_reachable_source: RefCell<Option<SourceId>>,
missed_sync_count: Cell<usize>,
}Fields
client: OnceCell<TokioDrop<Client>>The Matrix client for this session.
The list model of the sidebar.
user: OnceCell<User>The user of this session.
state: Cell<SessionState>The current state of the session.
is_homeserver_reachable: Cell<bool>Whether this session has a connection to the homeserver.
is_offline: Cell<bool>Whether this session is synchronized with the homeserver.
settings: OnceCell<SessionSettings>The current settings for this session.
global_account_data: OnceCell<GlobalAccountData>The settings in the global account data for this session.
notifications: NotificationsThe notifications API for this session.
ignored_users: IgnoredUsersThe ignored users API for this session.
user_sessions: UserSessionsListThe list of sessions for this session’s user.
security: SessionSecurityInformation about security for this session.
remote_cache: OnceCell<RemoteCache>The cache for remote data.
session_changes_handle: RefCell<Option<AbortHandle>>sync_handle: RefCell<Option<AbortHandle>>network_monitor_handler_id: RefCell<Option<SignalHandlerId>>homeserver_reachable_lock: Mutex<()>homeserver_reachable_source: RefCell<Option<SourceId>>missed_sync_count: Cell<usize>The number of missed synchronizations in a row.
Capped at MISSED_SYNC_DELAYS.len() - 1.
Implementations
Sourceimpl Session
impl Session
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl Session
impl Session
Sourcepub(super) fn set_client(&self, client: Client)
pub(super) fn set_client(&self, client: Client)
Set the Matrix client for this session.
The list model of the sidebar.
Sourcepub(super) fn verification_list(&self) -> VerificationList
pub(super) fn verification_list(&self) -> VerificationList
The verification list of this session.
Sourcefn set_state(&self, state: SessionState)
fn set_state(&self, state: SessionState)
Set the current state of the session.
Sourcefn homeserver_address(&self) -> NetworkAddress
fn homeserver_address(&self) -> NetworkAddress
The homeserver URL as a GNetworkAddress.
Sourcepub(super) async fn update_homeserver_reachable(&self)
pub(super) async fn update_homeserver_reachable(&self)
Check whether the homeserver is reachable.
Sourcefn set_is_homeserver_reachable(&self, is_reachable: bool)
fn set_is_homeserver_reachable(&self, is_reachable: bool)
Set whether the homeserver is reachable.
Sourcepub(super) fn set_offline(&self, is_offline: bool)
pub(super) fn set_offline(&self, is_offline: bool)
Set whether this session is synchronized with the homeserver.
Sourcefn global_account_data(&self) -> &GlobalAccountData
fn global_account_data(&self) -> &GlobalAccountData
The settings stored in the global account data for this session.
Sourcefn global_account_data_owned(&self) -> GlobalAccountData
fn global_account_data_owned(&self) -> GlobalAccountData
The owned settings stored in the global account data for this session.
Sourcepub(super) fn remote_cache(&self) -> &RemoteCache
pub(super) fn remote_cache(&self) -> &RemoteCache
The cache for remote data.
Sourcefn watch_session_changes(&self)
fn watch_session_changes(&self)
Watch the changes of the session, like being logged out or the tokens being refreshed.
Sourcefn handle_sync_response(
&self,
response: Result<SyncResponse, Error>,
) -> Option<Duration>
fn handle_sync_response( &self, response: Result<SyncResponse, Error>, ) -> Option<Duration>
Handle the response received via sync.
Returns the delay to wait for before making the next sync, if necessary.
Sourceasync fn init_user_profile(&self)
async fn init_user_profile(&self)
Load the cached profile of the user of this session.
Sourceasync fn update_user_profile(&self)
async fn update_user_profile(&self)
Update the profile of this session’s user.
Fetches the updated profile and updates the local data.
Sourcefn init_notifications(&self)
fn init_notifications(&self)
Start listening to notifications.
Sourceasync fn store_tokens(&self)
async fn store_tokens(&self)
Update the stored session tokens.